using System;
using System.Collections.Generic;
using Newtonsoft.Json;

namespace Alipay.AopSdk.Core.Domain
{
	/// <summary>
	///     AlipayEcoRenthouseRoomConcentrationSyncModel Data Structure.
	/// </summary>
	[Serializable]
	public class AlipayEcoRenthouseRoomConcentrationSyncModel : AopObject
	{
		/// <summary>
		///     户型-房  数值范围：1-26
		/// </summary>
		[JsonProperty("bedroom_count")]
		public long BedroomCount { get; set; }

		/// <summary>
		///     可入住时间 YYYY-MM-DD
		/// </summary>
		[JsonProperty("checkin_time")]
		public string CheckinTime { get; set; }

		/// <summary>
		///     小区Code，详见文档  http://ecopublic.oss-cn-hangzhou.aliyuncs.com/eco/tpmogo/CommunityInfos/CommunityInfos.xls
		/// </summary>
		[JsonProperty("community_code")]
		public string CommunityCode { get; set; }

		/// <summary>
		///     所在楼层  数值范围：1-99，不能大于房屋总楼层
		/// </summary>
		[JsonProperty("floor_count")]
		public long FloorCount { get; set; }

		/// <summary>
		///     押金   数值范围：0-￥420000.00
		/// </summary>
		[JsonProperty("foregift_amount")]
		public string ForegiftAmount { get; set; }

		/// <summary>
		///     免押金开始时间 YYYY-MM-dd
		/// </summary>
		[JsonProperty("free_begin_date")]
		public string FreeBeginDate { get; set; }

		/// <summary>
		///     免押金结束时间 YYYY-MM-dd
		/// </summary>
		[JsonProperty("free_end_date")]
		public string FreeEndDate { get; set; }

		/// <summary>
		///     通过"文件上传"接口返回的房源图片url路径。房间照片可录入0~10张,目前仅支持jpg、png、jpeg格式
		/// </summary>
		[JsonProperty("images")]
		
		public List<string> Images { get; set; }

		/// <summary>
		///     房源描述  字符串，最大字符长度400
		/// </summary>
		[JsonProperty("intro")]
		public string Intro { get; set; }

		/// <summary>
		///     集中式最高价格，支持小数点后面2位。  新增时必输字段，修改时如果不转值则以上次接口调用值为准。
		/// </summary>
		[JsonProperty("max_amount")]
		public string MaxAmount { get; set; }

		/// <summary>
		///     公寓别名  是否必须:（新增）是/（修改）否
		/// </summary>
		[JsonProperty("nickname")]
		public string Nickname { get; set; }

		/// <summary>
		///     其它费用
		/// </summary>
		[JsonProperty("other_amount")]
		
		public List<EcoRenthouseOtherAmount> OtherAmount { get; set; }

		/// <summary>
		///     管家姓名
		/// </summary>
		[JsonProperty("owners_name")]
		public string OwnersName { get; set; }

		/// <summary>
		///     管家电话  手机号码，必须为400开头
		/// </summary>
		[JsonProperty("owners_tel")]
		public string OwnersTel { get; set; }

		/// <summary>
		///     户型-厅  数值范围：0-10
		/// </summary>
		[JsonProperty("parlor_count")]
		public long ParlorCount { get; set; }

		/// <summary>
		///     付款方式（1：付一，2：付二）
		/// </summary>
		[JsonProperty("pay_type")]
		public long PayType { get; set; }

		/// <summary>
		///     出租状态   数值范围：1未租、2已租
		/// </summary>
		[JsonProperty("rent_status")]
		public long RentStatus { get; set; }

		/// <summary>
		///     出租类型 1：整租，2：合租
		/// </summary>
		[JsonProperty("rent_type")]
		public long RentType { get; set; }

		/// <summary>
		///     租金   数值范围：￥100.00 - ￥35000.00 ，支持小数点后面2位
		/// </summary>
		[JsonProperty("room_amount")]
		public string RoomAmount { get; set; }

		/// <summary>
		///     房间面积  数值范围：5.00㎡-300.00㎡，支持小数点后面2位
		/// </summary>
		[JsonProperty("room_area")]
		public string RoomArea { get; set; }

		/// <summary>
		///     KA内部存储的房源编号
		/// </summary>
		[JsonProperty("room_code")]
		public string RoomCode { get; set; }

		/// <summary>
		///     物品配置(房间)  2:空调;3:热水器;4:洗衣机;5:冰箱;6:电视;7:微波炉;8:燃气灶;9:抽油烟机;10:电磁炉;11:床;11:WIFI;12:书桌;13:衣柜;14:沙发;15:阳台;
		/// </summary>
		[JsonProperty("room_configs")]
		
		public List<string> RoomConfigs { get; set; }

		/// <summary>
		///     房源初始上下架状态  上架状态租房平台会展示该房间信息，下架状态反之
		/// </summary>
		[JsonProperty("room_status")]
		public long RoomStatus { get; set; }

		/// <summary>
		///     户型-卫  数值范围：0-10
		/// </summary>
		[JsonProperty("toilet_count")]
		public long ToiletCount { get; set; }

		/// <summary>
		///     房屋总楼层  数值范围：1-99，不能小于所在楼层
		/// </summary>
		[JsonProperty("total_floor_count")]
		public long TotalFloorCount { get; set; }
	}
}